@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import json
 import re
+from typing import Any
 
 from checkov.cloudformation.checks.resource.base_resource_check import BaseResourceCheck
 from checkov.common.models.enums import CheckResult, CheckCategories
@@ -8,14 +11,14 @@ ACCOUNT_ACCESS = re.compile(r'\d{12}|arn:aws:iam::\d{12}:root')
 
 
 class IAMRoleAllowAssumeFromAccount(BaseResourceCheck):
-    def __init__(self):
+    def __init__(self) -> None:
         name = "Ensure AWS IAM policy does not allow assume role permission across all services"
         id = "CKV_AWS_61"
-        supported_resources = ['AWS::IAM::Role']
-        categories = [CheckCategories.IAM]
+        supported_resources = ('AWS::IAM::Role',)
+        categories = (CheckCategories.IAM,)
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
-    def scan_resource_conf(self, conf):
+    def scan_resource_conf(self, conf: dict[str, Any]) -> CheckResult:
         properties = conf.get('Properties')
         if properties and 'AssumeRolePolicyDocument' in properties:
             assume_role_policy_doc = properties['AssumeRolePolicyDocument']
@@ -28,7 +31,7 @@ class IAMRoleAllowAssumeFromAccount(BaseResourceCheck):
             elif isinstance(assume_role_policy_doc, str):
                 try:
                     assume_role_block = json.loads(assume_role_policy_doc)
-                except Exception as e:
+                except Exception:
                     return CheckResult.UNKNOWN
             else:
                 assume_role_block = assume_role_policy_doc
@@ -39,7 +42,7 @@ class IAMRoleAllowAssumeFromAccount(BaseResourceCheck):
             if isinstance(assume_role_block['Statement'], list) and 'Principal' in \
                     assume_role_block['Statement'][0]:
                 if 'AWS' in assume_role_block['Statement'][0]['Principal']:
-                    if isinstance(assume_role_block['Statement'][0]['Principal']['AWS'],list) \
+                    if isinstance(assume_role_block['Statement'][0]['Principal']['AWS'], list) \
                             and isinstance(assume_role_block['Statement'][0]['Principal']['AWS'][0], str):
                         if re.match(ACCOUNT_ACCESS, assume_role_block['Statement'][0]['Principal']['AWS'][0]):
                             return CheckResult.FAILED
