@@ -37,7 +37,7 @@ class Seccomp(BaseK8Check):
                 metadata = conf["metadata"]
         elif conf['kind'] == 'CronJob':
             if "spec" in conf:
-                if "jobTemplate" in conf["spec"]:
+                if isinstance(conf["spec"], dict) and "jobTemplate" in conf["spec"]:
                     if "spec" in conf["spec"]["jobTemplate"]:
                         if conf["spec"]["jobTemplate"]["spec"] and "template" in conf["spec"]["jobTemplate"]["spec"]:
                             if "metadata" in conf["spec"]["jobTemplate"]["spec"]["template"]:
