@@ -71,7 +71,7 @@ def get_skipped_checks(entity_conf: dict[str, Any]) -> list[_SkippedCheck]:
         return skipped
     if "metadata" in entity_conf.keys():
         metadata = entity_conf["metadata"]
-    if "annotations" in metadata.keys() and metadata["annotations"] is not None:
+    if metadata and "annotations" in metadata.keys() and metadata["annotations"] is not None:
         if isinstance(metadata["annotations"], dict):
             metadata["annotations"] = force_list(metadata["annotations"])
         for annotation in metadata["annotations"]:
