@@ -391,13 +391,13 @@ def run(banner: str = checkov_banner, argv: list[str] = sys.argv[1:]) -> int | N
         return exit_code
     elif config.docker_image:
         if config.bc_api_key is None:
-            parser.error("--bc-api-key argument is required when using --docker-image")
+            parser.error("--bc-api-key argument is required when using --docker-image or --image")
             return None
         if config.dockerfile_path is None:
-            parser.error("--dockerfile-path argument is required when using --docker-image")
+            parser.error("--dockerfile-path argument is required when using --docker-image or --image")
             return None
         if config.branch is None:
-            parser.error("--branch argument is required when using --docker-image")
+            parser.error("--branch argument is required when using --docker-image or --image")
             return None
         files = [os.path.abspath(config.dockerfile_path)]
         runner = sca_image_runner()
@@ -690,17 +690,18 @@ class Checkov:
                                 'created it, not the token ID visible later on. If you are using environment variables, '
                                 'make sure they are properly set and exported.')
 
-            if self.config.repo_id is None and not self.config.list:
+            if not self.config.list:
                 # if you are only listing policies, then the API key will be used to fetch policies, but that's it,
-                # so the repo is not required
-                self.parser.error("--repo-id argument is required when using --bc-api-key")
-            elif self.config.repo_id:
-                repo_id_sections = self.config.repo_id.split('/')
-                if len(repo_id_sections) < 2 or any(len(section) == 0 for section in repo_id_sections):
-                    self.parser.error(
-                        "--repo-id argument format should be 'organization/repository_name' E.g "
-                        "bridgecrewio/checkov"
-                    )
+                # so the repo is not required and ignored
+                if self.config.repo_id is None:
+                    self.parser.error("--repo-id argument is required when using --bc-api-key")
+                else:
+                    repo_id_sections = self.config.repo_id.split('/')
+                    if len(repo_id_sections) < 2 or any(len(section) == 0 for section in repo_id_sections):
+                        self.parser.error(
+                            "--repo-id argument format should be 'organization/repository_name' E.g "
+                            "bridgecrewio/checkov"
+                        )
 
             try:
                 bc_integration.bc_api_key = self.config.bc_api_key
@@ -840,13 +841,13 @@ class Checkov:
             return exit_code
         elif self.config.docker_image:
             if self.config.bc_api_key is None:
-                self.parser.error("--bc-api-key argument is required when using --docker-image")
+                self.parser.error("--bc-api-key argument is required when using --docker-image or --image")
                 return None
             if self.config.dockerfile_path is None:
-                self.parser.error("--dockerfile-path argument is required when using --docker-image")
+                self.parser.error("--dockerfile-path argument is required when using --docker-image or --image")
                 return None
             if self.config.branch is None:
-                self.parser.error("--branch argument is required when using --docker-image")
+                self.parser.error("--branch argument is required when using --docker-image or --image")
                 return None
             files = [os.path.abspath(self.config.dockerfile_path)]
             runner = sca_image_runner()
